% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/checkRaw.R
\name{checkRaw}
\alias{checkRaw}
\alias{check_raw}
\alias{assertRaw}
\alias{assert_raw}
\alias{testRaw}
\alias{test_raw}
\alias{expect_raw}
\title{Check if an argument is a raw vector}
\usage{
checkRaw(x, len = NULL, min.len = NULL, max.len = NULL,
  names = NULL, null.ok = FALSE)

check_raw(x, len = NULL, min.len = NULL, max.len = NULL,
  names = NULL, null.ok = FALSE)

assertRaw(x, len = NULL, min.len = NULL, max.len = NULL,
  names = NULL, null.ok = FALSE, .var.name = vname(x), add = NULL)

assert_raw(x, len = NULL, min.len = NULL, max.len = NULL,
  names = NULL, null.ok = FALSE, .var.name = vname(x), add = NULL)

testRaw(x, len = NULL, min.len = NULL, max.len = NULL,
  names = NULL, null.ok = FALSE)

test_raw(x, len = NULL, min.len = NULL, max.len = NULL,
  names = NULL, null.ok = FALSE)

expect_raw(x, len = NULL, min.len = NULL, max.len = NULL,
  names = NULL, null.ok = FALSE, info = NULL, label = vname(x))
}
\arguments{
\item{x}{[any]\cr
Object to check.}

\item{len}{[\code{integer(1)}]\cr
Exact expected length of \code{x}.}

\item{min.len}{[\code{integer(1)}]\cr
Minimal length of \code{x}.}

\item{max.len}{[\code{integer(1)}]\cr
Maximal length of \code{x}.}

\item{names}{[\code{character(1)}]\cr
Check for names. See \code{\link{checkNamed}} for possible values.
Default is \dQuote{any} which performs no check at all.
Note that you can use \code{\link{checkSubset}} to check for a specific set of names.}

\item{null.ok}{[\code{logical(1)}]\cr
If set to \code{TRUE}, \code{x} may also be \code{NULL}.
In this case only a type check of \code{x} is performed, all additional checks are disabled.}

\item{.var.name}{[\code{character(1)}]\cr
Name of the checked object to print in assertions. Defaults to
the heuristic implemented in \code{\link{vname}}.}

\item{add}{[\code{AssertCollection}]\cr
Collection to store assertion messages. See \code{\link{AssertCollection}}.}

\item{info}{[character(1)]\cr
Extra information to be included in the message for the testthat reporter.
See \code{\link[testthat]{expect_that}}.}

\item{label}{[\code{character(1)}]\cr
Name of the checked object to print in messages. Defaults to
the heuristic implemented in \code{\link{vname}}.}
}
\value{
Depending on the function prefix:
 If the check is successful, the functions 
 \code{assertRaw}/\code{assert_raw} return 
 \code{x} invisibly, whereas
 \code{checkRaw}/\code{check_raw} and 
 \code{testRaw}/\code{test_raw} return 
 \code{TRUE}.
 If the check is not successful, 
 \code{assertRaw}/\code{assert_raw}
 throws an error message, 
 \code{testRaw}/\code{test_raw}
 returns \code{FALSE},
 and \code{checkRaw} returns a string with the error message.
 The function \code{expect_raw} always returns an
 \code{\link[testthat]{expectation}}.
}
\description{
Check if an argument is a raw vector
}
\examples{
testRaw(as.raw(2), min.len = 1L)
}
\seealso{
Other basetypes: \code{\link{checkArray}},
  \code{\link{checkAtomicVector}},
  \code{\link{checkAtomic}}, \code{\link{checkCharacter}},
  \code{\link{checkComplex}}, \code{\link{checkDataFrame}},
  \code{\link{checkDate}}, \code{\link{checkDouble}},
  \code{\link{checkEnvironment}},
  \code{\link{checkFactor}}, \code{\link{checkFormula}},
  \code{\link{checkFunction}},
  \code{\link{checkIntegerish}},
  \code{\link{checkInteger}}, \code{\link{checkList}},
  \code{\link{checkLogical}}, \code{\link{checkMatrix}},
  \code{\link{checkNull}}, \code{\link{checkNumeric}},
  \code{\link{checkPOSIXct}}, \code{\link{checkVector}}
}
\concept{basetypes}
